<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>YtbInputFactory</name>
    <message>
        <location filename="../ytbinputfactory.cpp" line="36"/>
        <source>Youtube Plugin</source>
        <translation>Втулок Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="70"/>
        <source>About Youtube Transport Plugin</source>
        <translation>Про транспортний втулок Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="71"/>
        <source>Qmmp Youtube Transport Plugin</source>
        <translation>Транспортний втулок Youtube для Qmmp</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="72"/>
        <source>This plugin adds feature to play audio from Youtube using %1 utility</source>
        <translation>Цей втулок додає функцію відтворення авдіо з Youtube за допомогою засобу %1</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="74"/>
        <source>%1 version: %2</source>
        <translation>%1 версія: %2</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="75"/>
        <source>Written by: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation>Розробник: Ілля Котов &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
    </message>
</context>
<context>
    <name>YtbInputSource</name>
    <message>
        <location filename="../ytbinputsource.cpp" line="185"/>
        <source>Uploader</source>
        <translation>Вивантажив</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="186"/>
        <source>Upload date</source>
        <translation>Дата вивантаження</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="187"/>
        <source>Duration</source>
        <translation>Тривалість</translation>
    </message>
</context>
</TS>
